/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Benoit Pelletier
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.ant.cluster;

import java.io.File;
import java.util.Iterator;

import org.objectweb.jonas.ant.jonasbase.BaseTaskItf;
import org.objectweb.jonas.ant.jonasbase.Discovery;

/**
 * Define DiscoveryCluster task
 * @author Benoit Pelletier
 */
public class DiscoveryCluster extends ClusterTasks {

    /**
     * Info for the logger
     */
    private static final String INFO = "[DiscoveryCluster] ";

    /**
     * greeting ports range
     */
    private String[] greetingPortRange = null;

    /**
     * source ports range
     */
    private String[] sourcePortRange = null;

    /**
     * multicast port
     */
    private String mcastPort = null;

    /**
     * multicast addr
     */
    private String mcastAddr = null;

    /**
     * ind of master node
     */
    private int masterNode = -1;


    /**
     * Default constructor
     */
    public DiscoveryCluster() {
        super();
    }

    /**
     * Set master node
     * @param masterNode inf of the master node
     */
    public void setMasterNode(int masterNode) {
        this.masterNode = masterNode;
    }

    /**
     * Set mcastPort
     * @param mcastPort multicast port to set
     */
    public void setMcastPort(String mcastPort) {
        this.mcastPort = mcastPort;
    }

    /**
     * Set mcastAddr
     * @param mcastAddr multicast address to set
     */
    public void setMcastAddr(String mcastAddr) {
        this.mcastAddr = mcastAddr;
    }

    /**
     * Set greeting ports range
     * @param portRange ports range
     */
    public void setGreetingPortRange(String portRange) {
        this.greetingPortRange = portRange.split(",");

    }

    /**
     * Set source ports range
     * @param portRange ports range
     */
    public void setSourcePortRange(String portRange) {
        this.sourcePortRange = portRange.split(",");

    }

    /**
     * Generates the discovery tasks for each JOnAS's instances
     */
    public void generatesTasks() {

        int portInd = 0;

        for (int i = getDestDirSuffixIndFirst(); i <= getDestDirSuffixIndLast(); i++) {

            String destDir = getDestDir(getDestDirPrefix(), i);
            log(INFO + "tasks generation for " + destDir);
            // creation of the Discovery tasks
            Discovery discovery = new Discovery();

            if (i == masterNode) {
                discovery.setSourcePort(sourcePortRange[portInd]);
            }
            discovery.setGreetingPort(greetingPortRange[portInd]);
            discovery.setMcastPort(mcastPort);
            discovery.setMcastAddr(mcastAddr);

            // set destDir for each carol task
            for (Iterator it = discovery.getTasks().iterator(); it.hasNext();) {
                BaseTaskItf task = (BaseTaskItf) it.next();
                task.setDestDir(new File(destDir));
            }

            addTasks(discovery);

            portInd++;

        }
    }
}