/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Florent BENOIT
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.ant.jonasbase;

import java.util.StringTokenizer;

import org.objectweb.jonas.ant.JOnASBaseTask;

/**
 * Allow to configure the JMS service
 * @author Florent Benoit
 */
public class Jms extends Tasks {

    /**
     * Info for the logger
     */
    private static final String INFO = "[JMS] ";

    /**
     * Default port number
     */
    private static final String DEFAULT_PORT = "16010";

    /**
     * Default initial topics
     */
    private static final String DEFAULT_TOPIC = "sampleTopic";

    /**
     * Name of the property for the Topics
     */
    private static final String TOPIC_PROPERTY = "Topic";

    /**
     * Name of the property for the Queues
     */
    private static final String QUEUE_PROPERTY = "Queue";

    /**
     * Default initial queues
     */
    private static final String DEFAULT_QUEUE = "sampleQueue";

    /**
     * Default constructor
     */
    public Jms() {
        super();
    }

    /**
     * Set the port number for Joram
     * @param portNumber the port for Joram
     */
    public void setPort(String portNumber) {

        // For JMS
        JReplace propertyReplace = new JReplace();
        propertyReplace.setConfigurationFile(JOnASBaseTask.JORAM_CONF_FILE);
        propertyReplace.setToken(DEFAULT_PORT);
        propertyReplace.setValue(portNumber);
        propertyReplace.setLogInfo(INFO + "Setting Joram port number to : " + portNumber + " in "
                + JOnASBaseTask.JORAM_CONF_FILE + " file.");
        addTask(propertyReplace);

        // for RAR file
        propertyReplace = new JReplace();
        propertyReplace.setConfigurationFile(JOnASBaseTask.JORAM_ADMIN_CONF_FILE);
        propertyReplace.setToken(DEFAULT_PORT);
        propertyReplace.setValue(portNumber);
        propertyReplace.setLogInfo(INFO + "Setting Joram port number to : " + portNumber + " in "
                + JOnASBaseTask.JORAM_ADMIN_CONF_FILE + " file.");
        addTask(propertyReplace);
    }

    /**
     * Set the initial topics when JOnAS start
     * @param initialTopics comma separated list of topics
     */
    public void setInitialTopics(String initialTopics) {
        JReplace propertyReplace = new JReplace();
        propertyReplace.setConfigurationFile(JOnASBaseTask.JORAM_ADMIN_CONF_FILE);
        propertyReplace.setToken(DEFAULT_TOPIC);
        String tokenValue = "";
        StringTokenizer st = new StringTokenizer(initialTopics, ",");

        while (st.hasMoreTokens()) {
            String topic = st.nextToken();
            if (st.hasMoreTokens()) {
                tokenValue += topic + "\n" + TOPIC_PROPERTY + "   ";
            } else {
                tokenValue += topic;
            }
        }

        propertyReplace.setValue(tokenValue);
        propertyReplace.setLogInfo(INFO + "Setting initial topics to : " + initialTopics);
        addTask(propertyReplace);
    }

    /**
     * Set the initial queues when JOnAS start
     * @param initialQueues comma separated list of topics
     */
    public void setInitialQueues(String initialQueues) {
        JReplace propertyReplace = new JReplace();
        propertyReplace.setConfigurationFile(JOnASBaseTask.JORAM_ADMIN_CONF_FILE);
        propertyReplace.setToken(DEFAULT_QUEUE);

        String tokenValue = "";
        StringTokenizer st = new StringTokenizer(initialQueues, ",");

        while (st.hasMoreTokens()) {
            String topic = st.nextToken();
            if (st.hasMoreTokens()) {
                tokenValue += topic + "\n" + QUEUE_PROPERTY + "   ";
            } else {
                tokenValue += topic;
            }
        }

        propertyReplace.setValue(tokenValue);
        propertyReplace.setLogInfo(INFO + "Setting initial queues to : " + initialQueues);
        addTask(propertyReplace);
    }
}