/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.container;

import java.util.Set;
import org.objectweb.jonas_ejb.deployment.api.MessageDrivenDesc;

import org.objectweb.jonas_ejb.container.JEntityFactory;
import org.objectweb.jonas_ejb.container.JMdbFactory;
import org.objectweb.jonas_ejb.container.JMdbEndpointFactory;

/**
 * This class implements the MessageDrivenBean type specified in JSR77
 * @author Adriana Danes
 *
 */
public class MessageDrivenBean extends EJB {

	JMdbEndpointFactory jmdbEndpointFactory = null;
	JMdbFactory jmdbFactory = null;

    /**
     * @param objectName JMX object name
     * @param factoryToManage JMdbFactory factory to manage
     */
    public MessageDrivenBean(String objectName, JMdbFactory factoryToManage) {
        super(objectName, factoryToManage);
        jmdbFactory = factoryToManage;
    }

    /**
     * @param objectName JMX object name
     * @param factoryToManage JMdbEndpointFactory factory to manage
     */
    public MessageDrivenBean(String objectName, JMdbEndpointFactory factoryToManage) {
        super(objectName, factoryToManage);
        jmdbEndpointFactory = factoryToManage;
    }

    /**
     * @return the name of the associate destination
     */
    public String getMdbJMSAssociateDestinationName() {
        return ((MessageDrivenDesc)ejbToManage.getDeploymentDescriptor()).getDestinationJndiName();
    }

    /**
     * return all the destination used by this ejb, including his associate destination
     * @return String set with the name of the Ejb Destinations
     */
    public Set getAllJMSDestinationName() {
        // call  the super method
        Set result = super.getAllJMSDestinationName();
        result.add(getMdbJMSAssociateDestinationName());
        return result;
    }

    /**
     * @return min-pool-size value
     */
    public int getMinPoolSize() {
    	if (jmdbEndpointFactory != null) {
    		return jmdbEndpointFactory.getMinPoolSize();
    	} else if (jmdbFactory != null) {
        	return jmdbFactory.getMinPoolSize();
    	} else {
    		return ((JMdbEndpointFactory) ejbToManage).getMinPoolSize();
    	}
    }

    /**
     * @return max-cache-size value
     */
    public int getMaxCacheSize() {
        if (jmdbEndpointFactory != null) {
            return jmdbEndpointFactory.getMaxCacheSize();
        } else if (jmdbFactory != null) {
            return jmdbFactory.getMaxCacheSize();
        } else {
            return ((JMdbEndpointFactory) ejbToManage).getMaxCacheSize();
        }
    }

    /**
     * @return  nb of instances (current cache size)
     */
    public int getCacheSize() {
        if (jmdbEndpointFactory != null) {
            return jmdbEndpointFactory.getCacheSize();
        } else if (jmdbFactory != null) {
            return jmdbFactory.getCacheSize();
        } else {
            return ((JMdbEndpointFactory) ejbToManage).getCacheSize();
        }
    }

    /**
     * @return pool-size value
     */
    public int getPoolSize() {
        if (jmdbEndpointFactory != null) {
            return jmdbEndpointFactory.getPoolSize();
        } else if (jmdbFactory != null) {
            return jmdbFactory.getPoolSize();
        } else {
            return ((JMdbEndpointFactory) ejbToManage).getPoolSize();
        }
    }
}
