/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.container;

import org.objectweb.jonas_ejb.container.JStatelessFactory;

/**
 * This class implements the StatelessSessionBean type specified in JSR77
 * @author Adriana Danes
 *
 */
public class StatelessSessionBean extends SessionBean {
        
    /**
     * @param objectName JMX object name
     * @param factoryToManage JStatelessFactory factory to manage
     */
    public StatelessSessionBean(String objectName, JStatelessFactory factoryToManage) {
        super(objectName, factoryToManage);
    }

    /**
     * Accessor for bean instances pool management.
     * @return the minimum size of the bean instances pool.
     */
    public int getMinPoolSize() {
        return ((JStatelessFactory)ejbToManage).getMinPoolSize();
    }

    /**
     * Accessor for bean instances pool management.
     * @return the maximum size of the bean instances pool
     */
    public int getMaxPoolSize() {
        return ((JStatelessFactory)ejbToManage).getMaxCacheSize();
    }
 
    /**
     * Accessor for bean instances pool management.
     * @return the current number of created bean instances
     */
    public int getNbInstances() {
        return ((JStatelessFactory)ejbToManage).getCacheSize();
    }

     /**
      * Operation for bean instances pool management.
      * Allows reducing the number of instances.
      */
    public void reducePoolToMinSize() {
        ((JStatelessFactory)ejbToManage).reduceCache();
    }
}
