/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2003-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.jmx;

import javax.management.ObjectName;

/**
 * A set of static classes used to build the names of Catalina MBeans used in JOnAS.
 * This class was initially located in package org.objectweb.jonas.webapp.jonasadmin.
 *
 * @author Michel-Ange ANTON
 */
public class CatalinaObjectName {

    public static ObjectName catalinaServer() {
        try {
            return ObjectName.getInstance("Catalina:type=Server");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaServices() {
        try {
            return ObjectName.getInstance("*:type=Service,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaServices(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Service, *");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaService(String p_Domain, String p_ServiceName) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Service,name=" + p_ServiceName);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaEngines() {
        try {
            return ObjectName.getInstance("*:type=Engine");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaEngine(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Engine");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaConnectors() {
        try {
            return ObjectName.getInstance("*:type=Connector");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaConnectors(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Connector,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaConnector(String p_Domain, String p_Port) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Connector,port=" + p_Port);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaHosts() {
        try {
            return ObjectName.getInstance("*:type=Host,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaHosts(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Host,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaHost(String p_Domain, String p_HostName) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Host,host=" + p_HostName);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaFactory() {
        try {
            return ObjectName.getInstance("Catalina:type=MBeanFactory");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaRealms() {
        try {
            return ObjectName.getInstance("*:type=Realm,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaRealm(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Realm");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaManager(String p_ServiceName, String p_Host, String p_Path) {
        try {
            return ObjectName.getInstance("Catalina:type=Manager,service=" + p_ServiceName + ",host="
                + p_Host + ",path=" + p_Path);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaLoader(String p_ServiceName, String p_Host, String p_Path) {
        try {
            return ObjectName.getInstance("Catalina:type=Loader,service=" + p_ServiceName + ",host="
                + p_Host + ",path=" + p_Path);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaValves() {
        try {
            return ObjectName.getInstance("*:type=Valve,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaValves(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Valve,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }
    public static ObjectName catalinaAccessLogValves(String p_Domain) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Valve,name=AccessLogValve,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaValves(String p_Domain, String p_Host) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Valve,host=" + p_Host + ",*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaValve(String p_Domain, String p_Name) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Valve,name=" + p_Name);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName catalinaValve(String p_Domain, String p_Name, String p_Host) {
        try {
            return ObjectName.getInstance(p_Domain + ":type=Valve,name=" + p_Name + ",host=" + p_Host);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

}
