/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.jmx;

import java.util.Set;
import java.util.Properties;
import javax.naming.Context;
import javax.management.AttributeList;
import javax.management.ObjectName;
import javax.management.MBeanInfo;

/**
 * Wraper class. Apply the management operations on the ManagementRep instance.
 * @author Adriana Danes
 */
public class JonasManagementRepr {

    /**
     * Using getManagementRepr() without parameters makes creating a ManagemenrReprImpl
     * object (an "old" style representant which uses proprietary RMIConnector object)
     */
    //private static ManagementRepr repr = ManagementReprFactory.getManagementRepr();
    // Let repr null and then use setRepr method, will allow to set/change representative
    // in order to set/change the managed server.
    private static ManagementRepr repr = null;

    /**
     * Test if repr null. This means that the ManagementRepFactory did not managed to instantiate the ManagementRep class.
     * @return true if ManagementRep not null
     */
    public static boolean reprNull() {
        if (repr == null) {
            return true;
        } else {
            return false;
        }
    }
    /**
     * @return True if the MBean is already registered in the MBean server, false otherwise or if an exception is catched.
     * @param on ObjectName of the MBean we are looking for
     */
    public static boolean isRegistered(ObjectName on) {
        return repr.isRegistered(on);
    }

    /**
     * @param on The ObjectName of the MBean from which the attribute is to be retrieved.
     * @param attribute A String specifying the name of the attribute to be retrieve.
     * @return The value of the attribute.
     */
    public static Object getAttribute(ObjectName on, String attribute)
        throws ManagementException
    {
        return repr.getAttribute(on, attribute);
    }

	/**
     * @param on The ObjectName of the MBean from which the attributes are to be retrieved.
     * @param attributes A String array specifying the names of the attributes to be retrieved.
     * @return The value of the attributes.
     */
    public static AttributeList getAttributes(ObjectName on, String[] attributes)
        throws ManagementException
    {
        return repr.getAttributes(on, attributes);
    }

    /**
     * @param on The ObjectName of the MBean within which the attribute is to be set.
     * @param attribute A String specifying the name of the attribute to be retrieve.
     * @param value The value to set to the attribute.
     */
    public static void setAttribute(ObjectName on, String attribute, Object value)
        throws ManagementException
    {
        repr.setAttribute(on, attribute, value);
    }

    /**
     * @param on
     */
    public static Object invoke(ObjectName on, String operation, Object[] param, String[] signature)
        throws ManagementException
    {
        return repr.invoke(on, operation, param, signature);
    }

    /**
     * @return A set containing the ObjectNames for the MBeans selected.
     */
    public static java.util.Set queryNames(ObjectName on) throws ManagementException
    {
        return repr.queryNames(on);
    }

    /**
     * @return An instance of MBeanInfo allowing the retrieval of all
     * attributes and operations of this MBean.
     */
    public static MBeanInfo getMBeanInfo(ObjectName name) throws ManagementException {
        return (MBeanInfo)repr.getMBeanInfo(name);
    }

    /**
     * @return Context the current application context.
     */
    public static Context getContext() throws javax.naming.NamingException {
        return repr.getContext();
    }
    /**
     * @return String the name of the current RMI connector.
     * Return null if no RMI connector is available.
     */
    public static String getCurrentRMIConnectorName() {
        return repr.getCurrentRMIConnectorName();
    }
    /**
     * Set the currentRMIConnectorName to the specified value
     */
    public static void setCurrentRMIConnectorName(String name) throws Exception {
        repr.setCurrentRMIConnectorName(name);
    }
    /**
     * Set the currentRMIConnectorName to null
     */
    public static void resetCurrentRMIConnectorName() {
        repr.resetCurrentRMIConnectorName();
    }
    /**
     * @return Set a set containning all RMI connector names available in the current context.
     */
    public static Set getRMIConnectorsNames() throws javax.naming.NamingException {
        return repr.getRMIConnectorsNames();
    }
    /**
     * @return String the value of the PROVIDER_URL property in the current context.
     */
    public static String getJonasNamingServiceURL() {
        return repr.getJonasNamingServiceURL();
    }
    /**
     * Sets  the PROVIDER_URL property to the specified value.
     */
    public static void setJonasNamingServiceURL(String url) throws javax.naming.NamingException {
        repr.setJonasNamingServiceURL(url);
    }

    /**
     * Create a new naming context based on the given env. properties
     * @param env properties to create a new naming context
     */
    public static void setNamingEnvCtx(Properties env) throws javax.naming.NamingException {
        repr.setNamingEnvCtx(env);
    }

    /**
     * @return Returns the repr.
     */
    public static ManagementRepr getRepr() {
        return repr;
    }

    /**
     * @param repr The repr to set.
     */
    public static void setRepr(ManagementRepr repr) {
        JonasManagementRepr.repr = repr;
    }
}
