/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.deploy;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;

/**
 * @author Patrick Smith
 * @author Gregory Lapouchnian
 */
public class ApplyDomainDeployAction extends BaseDeployAction {

    // --------------------------------------------------------- Public Methods

    /**
     */
    public ActionForward executeAction(ActionMapping p_Mapping,
            ActionForm p_Form, HttpServletRequest p_Request,
            HttpServletResponse p_Response) throws IOException,
            ServletException {

        String sForward = "Domain Deploy Confirm";

        // Form used
        DomainDeployForm oForm = (DomainDeployForm) p_Form;
        oForm.setDeploymentInProgress(false);
        oForm.setDeploymentComplete(false);
      
        try {

            // set the array lists of selected apps and target servers based on
            // the selections returned by struts
            ArrayList appList = new ArrayList();
            ArrayList serverList = new ArrayList();
            ArrayList serverNamesList = new ArrayList();

            for (int i = 0; i < oForm.getServerSelected().length; i++) {
                serverList.add(oForm.getServerSelected()[i]);
                serverNamesList.add(ObjectName.getInstance(oForm.getServerSelected()[i]).getKeyProperty("name"));
            }
            for (int i = 0; i < oForm.getDeploySelected().length; i++) {
                appList.add(oForm.getDeploySelected()[i]);
            }

            oForm.setListDeploy(appList);
            oForm.setListTargetServers(serverList);
            oForm.setListTargetServerNames(serverNamesList);

            // make sure that the action and the replacement option are transferred
            // to the next action
            oForm.setSelectedAction(oForm.getSelectedOption());
            oForm.setReplacementOption(oForm.getReplaceOnTarget());

            // fill up the report with initial values to display 'In Progress'
            // status
            Map blankReport = new TreeMap();
            Map initialStatus = new HashMap();
            initialStatus.put("In Progress...", "true");
            for (int i = 0; i < appList.size(); i++) {
                HashMap appReport = new HashMap();
                for (int j = 0; j < serverList.size(); j++) {
                    appReport.put(ObjectName.getInstance(
                            (String) serverList.get(j)).getKeyProperty("name"),
                           initialStatus);
                }
                blankReport.put(appList.get(i), appReport);
            }
            oForm.setReports(blankReport);

            // at least one entry must be selected from the list of servers and
            // from the list of applications
            oForm.setConfirm(oForm.getDeploySelected().length > 0
                    && oForm.getServerSelected().length > 0);

            if (!oForm.isConfirm()) {
                m_Errors.add("error.domain.deploy.noselect",
                             new ActionMessage("error.domain.deploy.noselect"));
                saveErrors(p_Request, m_Errors);
                sForward = getForwardEdit();
            }

        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward(sForward));
    }
}
