/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.deploy;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

/**
 * @author Patrick Smith
 *         Greg Lapouchnian
 */

public class DomainDeployForm extends ActionForm {

// --------------------------------------------------------- Constants

    public static final String DEPLOY = "deploy";
    public static final String UPLOAD = "upload";
    public static final String UPLOADDEPLOY = "uploadDeploy";

// --------------------------------------------------------- Properties variables


    // all the apps available for deployment
    private ArrayList listDeployable = new ArrayList();
    // all the servers in the domain
    private ArrayList listServers = new ArrayList();
    // the actual names of the servers in the domain
    private ArrayList listServerNames = new ArrayList();

    // the apps that were selected by the user to be deployed
    private ArrayList listDeploy = new ArrayList();
    // the target servers selected by the user
    private ArrayList listTargetServers = new ArrayList();
    // the names of the servers selected by the user
    private ArrayList listTargetServerNames = new ArrayList();

    // store the progress report to provide the user with feedback
    private Map reports = new TreeMap();

    private String deploy = null;

    // which deployment option was selected by the user
    private String selectedOption = null;
    // should applications with the same name be replaced during upload
    private boolean replaceOnTarget = false;
    // apps to deploy
    private String[] deploySelected = new String[0];
    // target servers
    private String[] serverSelected = new String[0];
    
    // has the user confirmed the deployment?
    private boolean confirm = false;
    // has the deployment finished?
    private boolean deploymentComplete = false;
    // is there a deployment operation in progress?
    private boolean deploymentInProgress = false;

    // the action to take
    private String selectedAction = null;
    // replace on target option
    private boolean replacementOption = false;
    
    // Has an exception occured during this operation.
    private boolean exception = false;
    
    // Is the archive type selected configurable.
    private boolean isConfigurable;

// --------------------------------------------------------- Public Methods

    /**
     * Reset all properties to their default values.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     */

    public void reset(ActionMapping mapping, HttpServletRequest request) {
        deploySelected = new String[0];
        serverSelected = new String[0];
        setSelectedOption(DEPLOY);
        replaceOnTarget = false;
        exception = false;
    }

    /**
     * Validate the properties that have been set from this HTTP request,
     * and return an <code>ActionErrors</code> object that encapsulates any
     * validation errors that have been found.  If no errors are found, return
     * <code>null</code> or an <code>ActionErrors</code> object with no
     * recorded error messages.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {
        ActionErrors oErrors = new ActionErrors();
        return oErrors;
    }

    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append(" listDeployable = ").append(listDeployable).append("\n");
        sb.append(" listServers = ").append(listServers).append("\n");
        sb.append(" listDeploy = ").append(listDeploy).append("\n");
        sb.append(" listTargetServers = ").append(listTargetServers).append("\n");
        sb.append(" reports = ").append(reports).append("\n");
        sb.append(" deploySelected = [");
        for (int i = 0; i < deploySelected.length; i++) {
            if (i > 0) {
                sb.append(", ");
            }
            sb.append(deploySelected[i]);
        }
        sb.append("]\n");
        sb.append(" serverSelected = [");
        for (int i = 0; i < serverSelected.length; i++) {
            if (i > 0) {
                sb.append(", ");
            }
            sb.append(serverSelected[i]);
        }
        sb.append("]\n");
        sb.append(" deploy = ").append(deploy).append("\n");
        sb.append(" complete = ").append(deploymentComplete).append("\n");
        sb.append(" progress = ").append(deploymentInProgress).append("\n");
        sb.append(" selectedOption = ").append(selectedOption).append("\n");
        sb.append(" replaceOnTarget = ").append(replaceOnTarget).append("\n");
        sb.append(" selectedAction = ").append(selectedAction).append("\n");
        sb.append(" replacementOption = ").append(replacementOption).append("\n");

        return sb.toString();
    }

// --------------------------------------------------------- Properties Methods
    
    public ArrayList getListServers() {
        return listServers;
    }

    public void setListServers(ArrayList listServers) {
        this.listServers = listServers;
    }
    
    public ArrayList getListServerNames() {
        return listServerNames;
    }

    public void setListServerNames(ArrayList listServerNames) {
        this.listServerNames = listServerNames;
    }    
    
    public Map getReports() {
        return reports;
    }

    public void setReports(Map reports) {
        this.reports = reports;
    }    

    public ArrayList getListTargetServers() {
        return listTargetServers;
    }

    public void setListTargetServers(ArrayList listTargetServers) {
        this.listTargetServers = listTargetServers;
    }
    
    public ArrayList getListTargetServerNames() {
        return listTargetServerNames;
    }

    public void setListTargetServerNames(ArrayList listTargetServerNames) {
        this.listTargetServerNames = listTargetServerNames;
    }    
    
    public ArrayList getListDeployable() {
        return listDeployable;
    }

    public void setListDeployable(ArrayList listDeployable) {
        this.listDeployable = listDeployable;
    }

    public String[] getDeploySelected() {
        return deploySelected;
    }

    public void setDeploySelected(String[] deploySelected) {
        this.deploySelected = deploySelected;
    }
    
    public String[] getServerSelected() {
        return serverSelected;
    }
    
    public void setServerSelected(String[] serverSelected) {
        this.serverSelected = serverSelected;
    }

    public ArrayList getListDeploy() {
        return listDeploy;
    }

    public void setListDeploy(ArrayList listDeploy) {
        this.listDeploy = listDeploy;
    }

    public String getDeploy() {
        return deploy;
    }

    public void setDeploy(String deploy) {
        this.deploy = deploy;
    }

    public boolean isConfirm() {
        return confirm;
    }

    public void setConfirm(boolean confirm) {
        this.confirm = confirm;
    }
    
    public boolean getDeploymentInProgress() {
        return deploymentInProgress;
    }

    public void setDeploymentInProgress(boolean deploymentInProgress) {
        this.deploymentInProgress = deploymentInProgress;
    }
    
    public boolean getDeploymentComplete() {
        return deploymentComplete;
    }
    
    public void setDeploymentComplete(boolean deploymentComplete) {
        this.deploymentComplete = deploymentComplete;
    }
    
    public String getSelectedOption() {
        return this.selectedOption;
    }
    
    public void setSelectedOption(String selectedOption) {
        this.selectedOption = selectedOption;
    }
    
    public String getSelectedAction() {
        return this.selectedAction;
    }
    
    public void setSelectedAction(String selectedAction) {
        this.selectedAction = selectedAction;
    }    
    
    public boolean getReplaceOnTarget() {
        return replaceOnTarget;
    }
    
    public void setReplaceOnTarget(boolean replaceChecked) {
        this.replaceOnTarget = replaceChecked;
    }
    
    public boolean getReplacementOption() {
        return replacementOption;
    }
    
    public void setReplacementOption(boolean replacementOption) {
        this.replacementOption = replacementOption;
    }    
    
    public boolean getException() {
        return exception;
    }
    
    public void setException(boolean exception) {
        this.exception = exception;
    }
    
    
    /**
     * Return if the current deployment type is configurable.
     * @return if the current deployment type is configurable.
     */
    public boolean getIsConfigurable() {
        return this.isConfigurable;
    }
    
    /**
     * Sets if the current deployment type is configurable.
     * @param isDomain if current deployment type is configurable.
     */
    public void setIsConfigurable(boolean isConfigurable) {
        this.isConfigurable = isConfigurable;
    }
    
}
