/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.domain;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.ManagementReprLoader;
import org.objectweb.jonas.webapp.jonasadmin.JonasBaseAction;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;
import org.objectweb.jonas.webapp.jonasadmin.common.BeanComparator;
import org.objectweb.jonas.webapp.jonasadmin.common.ObjectNameItem;

/**
 * @author Michel-Ange ANTON
 */

public class EditDomainAction extends JonasBaseAction {

// --------------------------------------------------------- Public Methods

	public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
			, HttpServletRequest p_Request, HttpServletResponse p_Response)
	throws IOException, ServletException {
		
		try {
			String adminServerName = m_WhereAreYou.getAdminJonasServerName();
			boolean changeManagement = false;
			if (!adminServerName.equals(m_WhereAreYou.getCurrentJonasServerName())) {
				// change management conext from a managed server in the domain 
				// to the JonasAdmin server
				ManagementReprLoader.loadServerRepr(adminServerName);
				m_WhereAreYou.refreshServers(p_Request);
				changeManagement = true;
			}
			
			// Force the node selected in tree
			m_WhereAreYou.selectNameNode("domain", true);
			
			if (changeManagement) {
				refreshServerTree(p_Request);
			}
			
			// Get servers running in this domain
			ObjectName onDomain = m_WhereAreYou.getCurrentDomain();
			ObjectName onCurrentServer = m_WhereAreYou.getCurrentJonasServer();
			String [] serversOn = (String[]) JonasManagementRepr.getAttribute(onDomain, "servers");
			ArrayList al = new ArrayList();
			
			String sOn = null;
			for (int i = 0; i < serversOn.length; i++) {
				sOn = serversOn[i];
				ObjectName onServer = ObjectName.getInstance(sOn);
				if (!onServer.equals(onCurrentServer)) {
					al.add(new ObjectNameItem(onServer));
				}
			}
			Collections.sort(al, new BeanComparator(new String[] {
			"name"}));
			p_Request.setAttribute("listServers", al);
			p_Request.setAttribute("currentServer", new ObjectNameItem(onCurrentServer));
		} catch (Throwable t) {
			addGlobalError(t);
			saveErrors(p_Request, m_Errors);
			return (p_Mapping.findForward("Global Error"));
		}
		// Forward to the jsp.
		return (p_Mapping.findForward("Domain"));
	}
	
}
