/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JonasObjectName;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;
import org.objectweb.jonas.webapp.jonasadmin.service.ejb.EjbItem;
import org.objectweb.jonas.webapp.jonasadmin.service.ejb.EjbItemByNameComparator;

/**
 * @author Frederic MAISTRE
 */

public class EditJoramLocalQueueAction extends EditJoramBaseAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping pMapping, ActionForm pForm
        , HttpServletRequest pRequest, HttpServletResponse pResponse)
        throws IOException, ServletException {

        
        String name = pRequest.getParameter("name");

        // Force the node selected in tree
        m_WhereAreYou.selectNameNode(getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                    + "joramplatform" + WhereAreYou.NODE_SEPARATOR
                    + "joramlocalserver" + WhereAreYou.NODE_SEPARATOR
                    + "joramlocalqueue" + name, true);
        
        try {
            // Form used
            JoramLocalQueueForm oForm = null;
            if (name != null) {
                // Build a new form
                oForm = new JoramLocalQueueForm();
                oForm.reset(pMapping, pRequest);
                // Attach the form to the session object
                m_Session.setAttribute("joramLocalQueueForm", oForm);
                // Object name used
                ObjectName oObjectName = JonasObjectName.joramQueue(name);
                oForm.setName(getStringAttribute(oObjectName, "JndiName"));
                oForm.setId(getStringAttribute(oObjectName, "AgentId"));
            } else {
                // Used last form in session
                oForm = (JoramLocalQueueForm) m_Session.getAttribute("joramLocalQueueForm");
            }

            // Populuate dependency list
            if (name != null) {
                ArrayList al = new ArrayList();
                String[] asParam = new String[1];
                String[] asSignature = new String[1];
                asSignature[0] = "java.lang.String";
                asParam[0] = name;
                ObjectName ejbServiceObjectName = JonasObjectName.ejbService();
                if (JonasManagementRepr.isRegistered(ejbServiceObjectName)) {
                    java.util.Iterator it = ((java.util.Set) JonasManagementRepr.invoke(
                            ejbServiceObjectName, "getJmsDestinationDependence", asParam
                            , asSignature)).iterator();
                    while (it.hasNext()) {
                        al.add(new EjbItem((ObjectName) it.next()));
                    }
                    // Sort by name
                    Collections.sort(al, new EjbItemByNameComparator());
                    // Set list in form
                    oForm.setListUsedByEjb(al);
                }
            }
        } catch (Throwable t) {
            return (treatError(t, pMapping, pRequest));
        }

        // Forward to the jsp.
        return (pMapping.findForward("JoramLocalQueue"));
    }

}
