/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or 1any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.jonasadmin.test.domain;


import junit.framework.TestSuite;

import org.objectweb.jonas.jonasadmin.test.util.JonasAdminAuth;
import org.objectweb.jonas.jonasadmin.test.util.JonasAdminTestCase;
import org.xml.sax.SAXException;

import com.meterware.httpunit.HttpUnitOptions;
import com.meterware.httpunit.HttpUnitUtils;
import com.meterware.httpunit.TableCell;
import com.meterware.httpunit.WebLink;
import com.meterware.httpunit.WebResponse;
import com.meterware.httpunit.WebTable;

/**
 * Define a class to add useful methods for test the examples
 *  - Execute the EditDomainAction
 * @author Paul Kemler
 */
public class F_JonasAdminDomain extends JonasAdminTestCase {

    /**
     * TITLE of 'OTHER SERVERS' TABLE
     */
    private static final String TITLE_OTHERSERVERS = "Other servers in domain";

    /**
     * Main method
     * @param args the arguments
     */
    public static void main(String[] args) {

        String testtorun = null;
        // Get args
        for (int argn = 0; argn < args.length; argn++) {
            String sArg = args[argn];
            if (sArg.equals("-n")) {
                testtorun = args[++argn];
            }
        }
        if (testtorun == null) {
            junit.textui.TestRunner.run(suite());
        } else {
            junit.textui.TestRunner.run(new F_JonasAdminDomain(testtorun));
        }
    }

    /**
     * Get a new TestSuite for this class
     * @return a new TestSuite for this class
     */
    public static TestSuite suite() {
        return new TestSuite(F_JonasAdminDomain.class);
    }

    /**
     * Setup need for these tests
     * jonasAdmin is required
     * @throws Exception if it fails
     */
    protected void setUp() throws Exception {
        super.setUp();

        if (wc.getCurrentPage().getURL() == null) {
            useWar("jonasAdmin");
            // login to jonas admin
            try {
                JonasAdminAuth.doValidAuth(wc, url);
            } catch (Exception e) {
                fail("authentification failed :  " + e);
            }
        } else {
            // if there was an error, the connection must be restablished
            try {
                wc.getFrameContents(FRAME_TREE);
            } catch (Exception e) {
                wc.getResponse(urlLogOut);
                // login to jonas admin
                try {
                    JonasAdminAuth.doValidAuth(wc, url);
                } catch (Exception auth) {
                    fail("authentification failed :  " + auth);
                }
            }
        }
    }


    /**
     * Constructor with a specified name
     * @param s name
     */
    public F_JonasAdminDomain(String s) {
        super(s, URL_JONASADMIN);
    }

    /**
     * Verify if it is the good link of the tree which is selected
     * @param wr The WebResponse of the 'tree' frame
     * @param name A string with the name of the link
     * @return a boolean. True if the name is found in the link, else false.
     */
    private boolean treeControlSelected (WebResponse wr, String name) {
        boolean isSelected = false;     // the result
        int nbSelectedLink = 0;         // number of selected link
        String attribut;                // value of class attribut

        // Get all links
        WebLink[] links;
        try {
            links = wr.getLinks();

            // Search links with the 'tree-control-selected' class attribut
            // and increase nbSelectedLink
            for (int i = 0; i < links.length; i++) {
                attribut = links[i].getAttribute("class");
                if (attribut.indexOf("tree-control-selected") != -1) {
                    nbSelectedLink++;
                }
            }

            if (nbSelectedLink == 1) {
                WebLink link = wr.getLinkWith(name);
                String content = link.getAttribute("class");
                if (content.indexOf("tree-control-selected") != -1) {
                    isSelected = true;
                }
            }
        } catch (SAXException e) {
            fail("No link was found. " + e);
        }

        return isSelected;
    }


    /**
     * Test Succesful Select
     * @throws Exception if it fails
     *
     */
    public void testSuccessfulSelect() throws Exception {

        // Disable errors of javascript
        HttpUnitOptions.setExceptionsThrownOnScriptError(false);

        // Get the frame "tree"
        WebResponse treeFrame = wc.getFrameContents(FRAME_TREE);

        // Create a request
        WebLink link = treeFrame.getLinkWith("Domain");
        link.click();

        // Get the frame "tree"
        treeFrame = wc.getFrameContents(FRAME_TREE);

        // Verify if the attribut class that values "tree-control-selected"
        // it is in a link with "Domain"
        if (!treeControlSelected(treeFrame, "Domain")) {
            fail("Domain is not selected in the tree.");
        }

        // Create a new request for going to another page
        link = treeFrame.getLinkWith("Services");
        link.click();

        // Get the frame "tree"
        treeFrame = wc.getFrameContents(FRAME_TREE);

        // Verify if the attribut class that values "tree-control-selected"
        // it is NOT in a link with "Domain"
        if (treeControlSelected(treeFrame, "Domain")) {
            fail("Domain is selected in the tree.");
        }


        // Create a new request for going to another page
        link = treeFrame.getLinkWith("Domain");
        link.click();

        // Get the frame "tree"
        treeFrame = wc.getFrameContents(FRAME_TREE);

        // Verify if the attribut class that values "tree-control-selected"
        // it is in a link with "Domain"
        if (!treeControlSelected(treeFrame, "Domain")) {
            fail("Domain is not selected in the tree.");
        }

    }

    /**
     * Test Succesful Server Link
     * @throws Exception if it fails
     *
     */
    public void testSuccesfulServerLink() throws Exception {

        // The expected link
        String expectedLink = URL_JONASADMIN + "EditJonasServer.do?select=jonas:j2eeType=J2EEServer,name=jonas";

        // Disable errors of javascript
        HttpUnitOptions.setExceptionsThrownOnScriptError(false);

        // Get the frame "tree"
        WebResponse treeFrame = wc.getFrameContents(FRAME_TREE);

        // Create a request
        WebLink link = treeFrame.getLinkWith("Domain");
        link.click();

        // Get the response
        WebResponse wr = wc.getFrameContents(FRAME_CONTENT);

        // Verify if the link of the JonasAdmin's server
        link = wr.getLinks()[0];
        String actualLink = link.getAttribute("href");
        actualLink = HttpUnitUtils.decode(actualLink);
        assertEquals("The link of the JonasAdmin's server is wrong.", expectedLink, actualLink);
    }

    /**
     * Test if there is not any other server in domain
     * @throws Exception if it fails
     *
     */
    public void testOtherServers() throws Exception {

        // Disable errors of javascript
        HttpUnitOptions.setExceptionsThrownOnScriptError(false);

        // Get the frame "tree"
        WebResponse treeFrame = wc.getFrameContents(FRAME_TREE);

        // Create a request
        WebLink link = treeFrame.getLinkWith("Domain");
        link.click();

        // Get the response
        WebResponse wr = wc.getFrameContents(FRAME_CONTENT);

        // Verify if there is the message "No other server in this domain!"
        WebTable wt = wr.getTableStartingWith(TITLE_OTHERSERVERS);
        TableCell cell = wt.getTableCell(1, 0);
        String content = cell.getText();
        if (content.indexOf("No other server in this domain!") == -1) {
            // Verify if there are a link for other servers
            WebLink[] wl = wr.getLinks();
            if (wl.length < 2) {
                fail("No links are found for other servers in domain.");
            } else {
                for (int i = 1; i < wt.getRowCount(); i++) {
                    cell = wt.getTableCell(i, 0);
                    if (!(cell.getLinks().length > 0)) {
                        fail("A link doesn't exist for a server");
                    }
                }
            }
        }
    }

    /**
     * Tear Down cleanUp action
     * @throws Exception if an error occurs
     */
    public void tearDown() throws Exception {
        super.tearDown();
    }

}